# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/teste/testtask/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {
         ...

        "classmap": [
            ...
            
            "packages/teste/testtask/database/seeds",
            
            ...
        ],
        "psr-4": {
            ...
            
            "Teste\\Testtask\\": "packages/teste/testtask/src",
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Teste\Testtask\Providers\TesttaskServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Testtask'  => Teste\Testtask\Facades\Testtask::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Teste\\TesttaskTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Teste\Testtask\Providers\TesttaskServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Teste\Testtask\Providers\TesttaskServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Teste\Testtask\Providers\TesttaskServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/testtask/{modulename}

**User**

    http://path-to-route-folder/user/testtask/{modulename}

**Public**

    http://path-to-route-folder/testtasks


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/testtask/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/testtask/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/testtask/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/testtask/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/testtask/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/testtask/{modulename}/{slug}
    METHOD: GET